# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`duo_unix`](#duo_unix): This class installs and configures duo for various Linux distros
* [`duo_unix::pam_config`](#duo_unix--pam_config): This class will configure PAM to require Duo
* [`duo_unix::pam_ssh_config`](#duo_unix--pam_ssh_config): This class sets sshd up to use PAM
* [`duo_unix::params`](#duo_unix--params): Default parameter values for the duo_unix module
* [`duo_unix::repo`](#duo_unix--repo): Add an apt/yum repo for Debian/RedHat based systems
* [`duo_unix::ssh_config`](#duo_unix--ssh_config): This command sets ssh up to require duo through ForceCommand

## Classes

### <a name="duo_unix"></a>`duo_unix`

Copyright © 2019 The Trustees of Indiana University
SPDX-License-Identifier: BSD-3-Clause

This class is the entry point for the duo_unix class. It will install and
configure duo for various Linux distros.

#### Examples

##### 

```puppet
include duo_unix
```

#### Parameters

The following parameters are available in the `duo_unix` class:

* [`usage`](#-duo_unix--usage)
* [`manage_pam`](#-duo_unix--manage_pam)
* [`manage_ssh`](#-duo_unix--manage_ssh)
* [`manage_repo`](#-duo_unix--manage_repo)
* [`ikey`](#-duo_unix--ikey)
* [`skey`](#-duo_unix--skey)
* [`host`](#-duo_unix--host)
* [`package_ensure`](#-duo_unix--package_ensure)
* [`config_ensure`](#-duo_unix--config_ensure)
* [`fallback_local_ip`](#-duo_unix--fallback_local_ip)
* [`failmode`](#-duo_unix--failmode)
* [`pushinfo`](#-duo_unix--pushinfo)
* [`autopush`](#-duo_unix--autopush)
* [`motd`](#-duo_unix--motd)
* [`prompts`](#-duo_unix--prompts)
* [`accept_env_factor`](#-duo_unix--accept_env_factor)
* [`proxy`](#-duo_unix--proxy)
* [`groups`](#-duo_unix--groups)
* [`show_diff`](#-duo_unix--show_diff)

##### <a name="-duo_unix--usage"></a>`usage`

Data type: `Enum['login', 'pam']`

Whether it is expected that duo will be enforced through ssh or pam

##### <a name="-duo_unix--manage_pam"></a>`manage_pam`

Data type: `Boolean`

Whether to alter the pam config to require Duo
The default is true

Default value: `$duo_unix::params::manage_pam`

##### <a name="-duo_unix--manage_ssh"></a>`manage_ssh`

Data type: `Boolean`

Whether to alter the ssh config to require Duo
The default is true

Default value: `$duo_unix::params::manage_ssh`

##### <a name="-duo_unix--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether to manage the duo repo
The default is true

Default value: `$duo_unix::params::manage_repo`

##### <a name="-duo_unix--ikey"></a>`ikey`

Data type: `String`

The Integration Key for Duo

##### <a name="-duo_unix--skey"></a>`skey`

Data type: `String`

The Secret Key for Duo

##### <a name="-duo_unix--host"></a>`host`

Data type: `StdLib::Host`

The API hostname (i.e. api-XXXXXXXX.duosecurity.com

##### <a name="-duo_unix--package_ensure"></a>`package_ensure`

Data type: `Enum['latest', 'present', 'absent']`

This controls the package and config states
The default is "present"

Default value: `$duo_unix::params::package_ensure`

##### <a name="-duo_unix--config_ensure"></a>`config_ensure`

Data type: `Enum['file', 'absent']`

This controls the presence or absense of the configuration file
The default is "file"

Default value: `$duo_unix::params::config_ensure`

##### <a name="-duo_unix--fallback_local_ip"></a>`fallback_local_ip`

Data type: `Enum['no', 'yes']`

If Duo Unix cannot detect the IP address of the client, setting
fallback_local_ip = yes will cause Duo Unix to send the IP address
of the server it is running on.
The default is "no"

Default value: `$duo_unix::params::fallback_local_ip`

##### <a name="-duo_unix--failmode"></a>`failmode`

Data type: `Enum['secure', 'safe']`

On service or configuration errors that prevent Duo authentication,
fail "safe" (allow access) or "secure" (deny access).
The default is "safe".

Default value: `$duo_unix::params::failmode`

##### <a name="-duo_unix--pushinfo"></a>`pushinfo`

Data type: `Enum['no', 'yes']`

Include information such as the command to be executed in the Duo
Push message. Either "yes" or "no".
The default is "no".

Default value: `$duo_unix::params::pushinfo`

##### <a name="-duo_unix--autopush"></a>`autopush`

Data type: `Enum['no', 'yes']`

Either "yes" or "no". Default is "no". If "yes", Duo Unix will
automatically send a push login request to the user's phone, falling back
on a phone call if push is unavailable. Note that this effectively disables
passcode authentication. If "no", the user will be prompted to choose an
authentication method.
When configured with autopush = yes, we recommend setting prompts = 1
The default is "no"

Default value: `$duo_unix::params::autopush`

##### <a name="-duo_unix--motd"></a>`motd`

Data type: `Enum['no', 'yes']`

Print the contents of /etc/motd to screen after a successful login. Either
"yes" or "no".
The default is "no"

Default value: `$duo_unix::params::motd`

##### <a name="-duo_unix--prompts"></a>`prompts`

Data type: `Integer[1, 3]`

If a user fails to authenticate with a second factor, Duo Unix will prompt
the user to authenticate again. This option sets the maximum number of
prompts that Duo Unix will display before denying access.
Must be 1, 2, or 3.
Default is 3.

Default value: `$duo_unix::params::prompts`

##### <a name="-duo_unix--accept_env_factor"></a>`accept_env_factor`

Data type: `Enum['no', 'yes']`

Look for factor selection or passcode in the $DUO_PASSCODE environment
variable before prompting the user for input. When $DUO_PASSCODE is
non-empty, it will override autopush.
Default is "no"

Default value: `$duo_unix::params::accept_env_factor`

##### <a name="-duo_unix--proxy"></a>`proxy`

Data type: `Optional[StdLib::Httpurl]`

Whether to use a proxy.

Default value: `undef`

##### <a name="-duo_unix--groups"></a>`groups`

Data type: `Optional[String]`

The groups to assign.

Default value: `undef`

##### <a name="-duo_unix--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to display differences when the file changes.

Default value: `true`

### <a name="duo_unix--pam_config"></a>`duo_unix::pam_config`

Copyright © 2019 The Trustees of Indiana University
SPDX-License-Identifier: BSD-3-Clause

This class sets up the appropriate file in the PAM stack to require Duo 2fa
to successfully authenticate.

#### Examples

##### 

```puppet
include duo_unix::pam_config
```

### <a name="duo_unix--pam_ssh_config"></a>`duo_unix::pam_ssh_config`

Copyright © 2019 The Trustees of Indiana University
SPDX-License-Identifier: BSD-3-Clause

This class will set the following parameters in the sshd_config file
  * UsePAM                          yes
  * UseDNS                          no
  * ChallengeResponseAuthentication yes

#### Examples

##### 

```puppet
include duo_unix::pam_ssh_config
```

### <a name="duo_unix--params"></a>`duo_unix::params`

Copyright © 2019 The Trustees of Indiana University
SPDX-License-Identifier: BSD-3-Clause

This class just holds some parameter values for use elsewhere

### <a name="duo_unix--repo"></a>`duo_unix::repo`

Copyright © 2019 The Trustees of Indiana University
SPDX-License-Identifier: BSD-3-Clause

This class will add a repository to use to install the duo_unix package
from Duo Inc.

#### Examples

##### 

```puppet
include duo_unix::repo
```

### <a name="duo_unix--ssh_config"></a>`duo_unix::ssh_config`

This class sets values in the sshd config file.
Specifically:
  * ForceCommand       /usr/sbin/login_duo
  * PermitTunnel       no

#### Examples

##### 

```puppet
include duo_unix::ssh_config
```

